import "Turbine";
import "Turbine.Gameplay";
import "Turbine.UI";
import "Turbine.UI.Lotro";

Timerarea = class(Turbine.UI.Window);
function Timerarea:Constructor()
	Turbine.UI.Window.Constructor( self );

	self.settings = TimerareaLoadSettings();

	self:SetSize(78,90);
	self:SetPosition( self.settings.x, self.settings.y );
	self:SetOpacity(0.85);
	self:SetBackColor(Turbine.UI.Color(0.3,0.3,0.3));

	self.Duration=self.settings.dur;
	self.Labeltime = math.floor(self.Duration);
	self.Remaintime = self.Duration ;
	self.Endtime = 0;
	self.cm=settings.cm;

	self.dragging = false;
	self.move = true;
	self.running = false;
	self.loaded = false;
	self.player = Turbine.Gameplay.LocalPlayer.GetInstance();

	self.Timebutton=Turbine.UI.Button();
	self.Timebutton:SetParent(self);
	self.Timebutton:SetFont(Turbine.UI.Lotro.Font.TrajanProBold36);
	self.Timebutton:SetText( tostring(self.LabelTime) );
	self.Timebutton:SetPosition( 4, 16 );
	self.Timebutton:SetSize( 70, 70 );
	self.Timebutton:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleCenter );

	self:SetButtonImg(1);
    self.Timebutton:SetBlendMode(Turbine.UI.BlendMode.Overlay);
    self.Timebutton:SetBackColorBlendMode(Turbine.UI.BlendMode.Overlay);

	self.Timebutton.MouseClick = function(sender, args)
		if args.Button == Turbine.UI.MouseButton.Left then

			if self.running then
				self:SetButtonImg(1);
				self.running = false;
				self:SetWantsUpdates(false);

			else
				self:SetButtonImg(2);
				self.running = true;
				time = Turbine.Engine.GetGameTime();
				self.Endtime = time + self.Remaintime ;
				self:SetWantsUpdates(true);
			end

		elseif args.Button == Turbine.UI.MouseButton.Right then
			self:ResetTimer();
		end
	end

	self.Swordbutton=Turbine.UI.Button();
	self.Swordbutton:SetParent(self);
	self.Swordbutton:SetPosition( 62, 0 );
	self.Swordbutton:SetSize( 16, 16 );
	self:setCMImg();
    self.Swordbutton:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend);
    self.Swordbutton:SetBackColorBlendMode(Turbine.UI.BlendMode.AlphaBlend);

	self.Swordbutton.MouseClick = function(sender, args)
		if args.Button == Turbine.UI.MouseButton.Left then
			self.cm = not self.cm;
			settings.cm = self.cm;
			self:setCMImg();
		else
		end
	end

	self.player.InCombatChanged = function (sender,args)
		if self.cm then
			if self.player:IsInCombat() == true then
				if not self.running then
					self:SetButtonImg(2);
					self.running = true;
					time = Turbine.Engine.GetGameTime();
					self.Endtime = time + self.Remaintime ;
					self:SetWantsUpdates(true);
				end
			else
				if self.running then
					self:SetButtonImg(1);
					self.running = false;
					self:SetWantsUpdates(false);
					self:ResetTimer();
				end
			end
		end
	end
	self:ColorSet(1);

end

function Timerarea:SetButtonImg(mode)
	if mode==1 then
		self.Timebutton:SetBackground("Mooborn/Slugtimer/image/start_timer.tga");
	elseif mode==2 then
		self.Timebutton:SetBackground("Mooborn/Slugtimer/image/pause_timer.tga");
	else
		self.Timebutton:SetBackground("Mooborn/Slugtimer/image/start_timer.tga");	
	end
end

function Timerarea:setCMImg(args)
	if self.cm then
		self.Swordbutton:SetBackground("Mooborn/Slugtimer/image/sword_on.tga");
	else
		self.Swordbutton:SetBackground("Mooborn/Slugtimer/image/sword_off.tga");
	end
end

function Timerarea:MouseDown(args)
	if args.Button == Turbine.UI.MouseButton.Left and self.move then
		self.dragStartX = args.X;
		self.dragStartY = args.Y;
		self.dragging = true;
	end
end

function Timerarea:MouseMove(args)

	if self.dragging then
		local x, y = self:GetPosition();
		x = x + (args.X - self.dragStartX);
		y = y + (args.Y - self.dragStartY);
		settings.x = x;
		settings.y = y;
		self:SetPosition(x, y);
	end
end

function Timerarea:MouseUp(args)
	if args.Button == Turbine.UI.MouseButton.Left then
		self:SlugSaveSettings();
		self.dragging = false;
	end
end

function Timerarea:ColorSet(mode)
	if mode==1 then
		-- blue
		self.Timebutton:SetBackColor(Turbine.UI.Color(0.8,0,0.6,0.6));
	elseif mode==2 then
		-- yellow
		self.Timebutton:SetBackColor(Turbine.UI.Color(0.8,0.6,0.6,0));
	elseif mode==3 then
		-- red
		self.Timebutton:SetBackColor(Turbine.UI.Color(0.8,0.6,0,0));
	else
		-- blue
		self.Timebutton:SetBackColor(Turbine.UI.Color(0.8,0,0.6,0.6));
	end
end

function Timerarea:ResetTimer(args)

	local time = Turbine.Engine.GetGameTime();
	if self.running then
		self:SetWantsUpdates(false);
	end

	self.Remaintime = self.Duration;
	self.Labeltime= self.Duration;
	self.Endtime= time + self.Duration;
	self.Timebutton:SetText( tostring(self.Labeltime) );
	self:ColorSet(1);
	if self.running then
		self:SetWantsUpdates(true);
	end
end

function Timerarea:SetDuration(dur)
	self.Duration=dur;
	settings.dur=dur;
end

function Timerarea:Update()

	local time = Turbine.Engine.GetGameTime();

	if time > self.Endtime then
		self:ResetTimer();
	else
		self.Remaintime = self.Endtime - time;

		if math.floor(self.Remaintime)+1 < self.Labeltime then
			self.Labeltime = math.floor(self.Remaintime)+1;
			self.Timebutton:SetText( tostring(self.Labeltime) );

			if self.Remaintime < 2 then
				self:ColorSet(3);
			elseif self.Remaintime < 5 then
				self:ColorSet(2);
			else
				self:ColorSet(1);
			end
		end
	end
end

function Timerarea:MouseClick(args)
	if args.Button == Turbine.UI.MouseButton.Right then
		self.running=false;
		self:SetWantsUpdates(false);
		self:SetVisible(false);
		self:SetButtonImg(1);
		self:SlugSaveSettings();
		self:Close();
	end
end

function TimerareaLoadSettings()
	settings = Turbine.PluginData.Load( Turbine.DataScope.Character, "Slugtimer" );
	if type( settings ) ~= "table" then
		settings={ };
	end
	if (not settings.x) then settings.x = 400; end
	if (not settings.y) then settings.y = 400; end
	if (not settings.dur) then settings.dur = 60; end
	if (settings.cm == nil) then settings.cm = true; end
	return settings;
end

function Timerarea:SlugSaveSettings()
	Turbine.PluginData.Save( Turbine.DataScope.Character, "Slugtimer", self.settings );
end
